@@ -20,10 +20,13 @@
 #include "gl-application.h"
 
 #include <glib/gi18n.h>
+#include <libhandy-1/handy.h>
 
 #include "gl-categorylist.h"
 #include "gl-eventtoolbar.h"
 #include "gl-eventviewlist.h"
+#include "gl-journal.h"
+#include "gl-journal-model.h"
 #include "gl-util.h"
 #include "gl-window.h"
 
@@ -35,6 +38,7 @@ struct _GlApplication
 
 typedef struct
 {
+    GlJournal *journal;
     GSettings *desktop;
     GSettings *settings;
     gchar *monospace_font;
@@ -54,10 +58,13 @@ on_new_window (GSimpleAction *action,
 {
     GtkApplication *application;
     GtkWidget *window;
+    GlApplicationPrivate *priv;
 
     application = GTK_APPLICATION (user_data);
+    priv = gl_application_get_instance_private (GL_APPLICATION (application));
 
     window = gl_window_new (GTK_APPLICATION (application));
+    gl_window_load_journal (GL_WINDOW (window), priv->journal);
     gtk_widget_show (window);
 }
 
@@ -193,32 +200,63 @@ gl_application_startup (GApplication *application)
     /* Calls gtk_init() with no arguments. */
     G_APPLICATION_CLASS (gl_application_parent_class)->startup (application);
 
+    /* Initialize libhandy widgets and styling */
+    hdy_init ();
+
     /* gtk_init() calls setlocale(), so gettext must be called after that. */
     g_set_application_name (_(PACKAGE_NAME));
     gtk_window_set_default_icon_name (PACKAGE_TARNAME);
+
+    /* Opt-in to color scheme user preference. */
+    hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
+                                        HDY_COLOR_SCHEME_PREFER_LIGHT);
 }
 
 static void
-gl_application_activate (GApplication *application)
+launch_window (GApplication *application)
 {
     GtkWidget *window;
     GlApplicationPrivate *priv;
     const gchar * const close_accel[] = { "<Primary>w", NULL };
     const gchar * const search_accel[] = { "<Primary>f", NULL };
+    const gchar * const export_accel[] = { "<Primary>e", NULL };
+    const gchar * const help_accel[] = { "F1", NULL };
+    const gchar * const new_window_accel[] = { "<Primary>n", NULL };
+    const gchar * const help_overlay_accel[] = { "<Primary>question", NULL };
+
+    priv = gl_application_get_instance_private (GL_APPLICATION (application));
 
     window = gl_window_new (GTK_APPLICATION (application));
+    gl_window_load_journal (GL_WINDOW (window), priv->journal);
     gtk_widget_show (window);
     gtk_application_set_accels_for_action (GTK_APPLICATION (application),
                                            "win.close", close_accel);
     gtk_application_set_accels_for_action (GTK_APPLICATION (application),
                                            "win.search", search_accel);
-
-    priv = gl_application_get_instance_private (GL_APPLICATION (application));
+    gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+                                           "win.export", export_accel);
+    gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+                                           "app.help", help_accel);
+    gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+                                           "app.new-window", new_window_accel);
+    gtk_application_set_accels_for_action (GTK_APPLICATION (application),
+                                           "win.show-help-overlay",
+                                           help_overlay_accel);
 
     on_monospace_font_name_changed (priv->desktop, DESKTOP_MONOSPACE_FONT_NAME,
                                     priv);
 }
 
+static void
+gl_application_activate (GApplication *application)
+{
+    GlApplicationPrivate *priv;
+
+    priv = gl_application_get_instance_private (GL_APPLICATION (application));
+    priv->journal = gl_journal_new (NULL);
+    launch_window (application);
+}
+
 static const GOptionEntry options[] =
 {
     { "version", 'v', 0, G_OPTION_ARG_NONE, NULL,
@@ -239,6 +277,33 @@ gl_application_handle_local_options (GApplication *application,
     return -1;
 }
 
+static void
+gl_application_open (GApplication *application,
+                     GFile **files,
+                     gint n_files,
+                     const gchar *hint)
+{
+    gint i;
+    GPtrArray *array;
+    GlApplicationPrivate *priv;
+
+    priv = gl_application_get_instance_private (GL_APPLICATION (application));
+
+    array = g_ptr_array_new ();
+    for (i = 0; i < n_files; i++)
+    {
+        GFile *file;
+
+        file = files[i];
+        g_ptr_array_add (array, g_file_get_path (file));
+    }
+
+    g_ptr_array_add (array, NULL);
+
+    priv->journal = gl_journal_new (array);
+    launch_window (application);
+}
+
 static void
 gl_application_finalize (GObject *object)
 {
@@ -252,6 +317,8 @@ gl_application_finalize (GObject *object)
     g_clear_object (&priv->settings);
     g_clear_pointer (&priv->monospace_font, g_free);
 
+    g_clear_object (&priv->journal);
+
     G_OBJECT_CLASS (gl_application_parent_class)->finalize (object);
 }
 
@@ -262,6 +329,8 @@ gl_application_init (GlApplication *application)
     gchar *changed_font;
     GAction *action;
 
+    g_application_set_flags (G_APPLICATION (application), G_APPLICATION_HANDLES_OPEN);
+
     priv = gl_application_get_instance_private (application);
 
     priv->monospace_font = NULL;
@@ -297,6 +366,7 @@ gl_application_class_init (GlApplicationClass *klass)
 
     app_class = G_APPLICATION_CLASS (klass);
     app_class->activate = gl_application_activate;
+    app_class->open = gl_application_open;
     app_class->startup = gl_application_startup;
     app_class->handle_local_options = gl_application_handle_local_options;
 }
